Module sys

Module sys 

JavaScript system types that are re-exported by js-sys.

These types represent fundamental JavaScript values and are designed to be used as generic type parameters in typed JavaScript collections and APIs.

Structs

JsNullable
A nullable JS value of type T.
JsOption
An optional JS value of type T.
Null
The JavaScript null value.
Undefined
The JavaScript undefined value.

Traits

Promising
Marker trait for types which represent Resolution or Promise<Resolution>.